(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    210375,       3919]
NotebookOptionsPosition[    203363,       3812]
NotebookOutlinePosition[    203919,       3833]
CellTagsIndexPosition[    203876,       3830]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 8, Section 8.2, Figure 8.4b,d", "Section",ExpressionUUID->"384fa5da-6304-454d-a112-e1d6b3a3ebe9"],

Cell["\<\
We start by defining the radius as a function of semi-major axis, \
eccentricity and true anomaly.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fd6f1029-ac86-4604-bcdc-afd5feebc4e9"],

Cell["r[a_,e_,t_]:=a(1-e^2)/(1+e Cos[t]);", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"f94a2feb-6fc9-4490-8bb4-d246ab9e628e"],

Cell["Define a graphics object to represent the Sun.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d1965594-517b-4ce2-8e7b-4372f5329167"],

Cell["sun=Graphics[{PointSize[0.05],Point[{0,0}]}];", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"2ab9912e-1ca2-4a06-8dea-8191f83f3abf"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["ksolve", "Input"],
 " that solves Kepler's equation to find the eccentric anomaly for a given \
value of the mean anomaly and eccentricity."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8115818266696997`*^9, 3.811581829602481*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7513f64c-6edd-4abb-b03c-69a5c75da418"],

Cell["ksolve[ma_, e_] := FindRoot[ea - e Sin[ea] == ma, {ea,ma}];", "Input",
 CellChangeTimes->{{3.8115826442957373`*^9, 3.8115826789388227`*^9}, 
   3.811582717483737*^9},
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"524fa5d6-4078-4d61-942c-1edbd3dd4b1a"],

Cell[TextData[{
 "The function ",
 StyleBox["position", "Input"],
 " calculates the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " coordinates of an object for a particular value of the mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6366915b-f826-4109-8996-bf4f2704eaf4"],

Cell["\<\
position[ma_,a_,e_]:=
(eca=ea /. ksolve[ma,e];
x=N[a(Cos[eca]-e)]; y=N[a Sqrt[1-e^2] Sin[eca]];
{x,y})\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"31f6883c-7284-48b0-ab8d-b6bf58ec233e"],

Cell[TextData[{
 "Define a function ",
 StyleBox["PlotPath", "Input"],
 " to show points along the orbital path in the rotating frame of the \
resonant orbit defined by the list of two numbers in ",
 StyleBox["pl", "Input"],
 ".  The points are plotted at time intervals of ",
 StyleBox["dt", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ae5d1cc0-1b26-4be2-9f63-d3e13da369d3"],

Cell["\<\
PlotPath[pl_List, a_, e_, dt_] :=
Module[{time, p1, p2, p = Apply[Rational,pl],
        pt = If[pl[[1]] > pl[[2]], pl[[1]], pl[[2]]],
        sun=Graphics[{PointSize[0.05],Point[{0,0}]}],
        box = 
        Graphics[Line[{{-1.5,-1.5},{1.5,-1.5},
                       {1.5,1.5},{-1.5,1.5},{-1.5,-1.5}}]]},
  time = Table[N[t], {t,0,pt*2*Pi,dt}];
  posvec = Map[position[#,a,e]&,time];
  f = Map[N[ArcTan[#[[1]],#[[2]]]]&,posvec];
  rad = Map[N[Sqrt[#[[1]]^2+#[[2]]^2]]&,posvec];
  points = Transpose[{rad*Cos[p*time-f],rad*Sin[p*time-f]}];
  p1 = 
  ListPlot[points,
           AspectRatio->Automatic, Axes->None,
           PlotStyle->AbsolutePointSize[2], 
           DisplayFunction->Identity,
           PlotRange->{{-1.5,1.5},{-1.5,1.5}}];
  Show[box,sun,p1,DisplayFunction->$DisplayFunction,
  AspectRatio->Automatic,PlotRange->All]]\
\>", "Input",
 CellChangeTimes->{{3.811582750027729*^9, 3.811582781252552*^9}, {
  3.811582875303917*^9, 3.8115829029904423`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[5]:=",ExpressionUUID->"1bbdbe42-6c15-4a92-a117-aaa5121ae5c5"],

Cell["\<\
Plot points along the paths of orbits at the 3:1internal resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fa6b0c9a-760c-49c9-8daa-019f43e312cc"],

Cell["\<\
p1 = PlotPath[{1,3}, 1.0, 0.1, Pi/20];
p2 = PlotPath[{1,3}, 1.0, 0.2, Pi/20];
p3 = PlotPath[{1,3}, 1.0, 0.3, Pi/20];
p4 = PlotPath[{1,3}, 1.0, 0.4, Pi/20];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[6]:=",ExpressionUUID->"7cf91013-d2f5-43f2-aab5-7be9457b1566"],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.811581947954173*^9, 3.8115819505564413`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fd8fa469-17f5-4d21-a504-5d0aae5cc2cb"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{
  3.811581956475004*^9, {3.8115822806043673`*^9, 3.811582283369939*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[10]:=",ExpressionUUID->"8e37d426-a325-4eef-8597-181b45faea80"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVlXlQk1cUxUFQlrqgUpfakYIyagBBUdBKvWEYlSqggENRpI4siiyjFOpu
MdRRsKIIpQRFcCtYF6oSQAqZS2xowIIsIYUIJiayJJA9KlgLtvJeOuOb+eb7
483b7j3ndxyj9oXETjAzMzv83/f+39z0fqjAjI52tq0hL1sFyysYtkznOkxl
s9wmSYbgvjApIWy0BdXDl/IW1AzCHK8ZInlxJ941Pnjtv0wJY4FH6sP+kmBE
HC91XcAAtD3zKZb8Lsc09x02UXP74NFXBqFVax86c66wUkrkcO+QRww3Q4Ha
IIvV9ubPYSRkaUufchDnjq5MdE58Cuu733n8oVchb65su+u1Dtj8LJVz4ooG
f+n1ndyQ3AwCgWBG3rAWnSF7+sGTPNj3RaNf1TEdNsnEZ+ITSyBFbIxJ79Ah
N9uzXVN3E4vnVJc3WOox32ub87cCHr5g1i5ynaZH7QNg4uxm7PbMzGK+0iGn
z5Udb92BH2/Z6pj2UIcC7qeMxSFivJHl1wzbdWj3cq9tepQEzc0dJElVWiws
eD9kqFG7FaiPanBkzSY/c+kL7KkK36CwUOOItbfQd6wPL9U1mM8LHsKFEwfe
aIwDWB2exGLEKtEjbY9NYK0SW6IPsmt9B/Bo+PQTa0KH0FB4/ky+ohdVv23Z
uZCjQl8nRZsgQo6VS6oMerEaj69NqyhYI0VRSsG+KajBR9tSXxVEi3HlAri/
N1KLVeWa7CveQiyf7u9WVKbFu6dbwyxONmJMbEbnrDtazOhqWh4HD/E6k3U3
crMWLTevfb3/SSakLhs5zsrR4D2u+H7cTIT1607lXtyvRqekAdHzA82wKqj/
57j+IWyo5C7I+kkEHnlG0ahBiUW2S2TB3j2wxCUgYxd7APmOirAda2UQH9oO
U3t68ek5xYofnXohJtXayBDI8IRh97nPH/ZD27j+ejD2drq3tV4BKn/LMVGO
CBuK9dlneIPgbs+tlFo1YaMFv0XpqAL/3d/F282qRqFPMi9wqhq0HvaKS15s
CLwTHNpxSg3f5Ofyz8Y9Au/qecucz6vhsMtW++SyVrDzTLSpc1PD5b/LRuZ1
dULMvYQjjAQVRL54q8gplMCKAKtch+AhkO5OcrQ8IIdVzBKGWKmE1pOd705H
9kF0TZ0kDRQw+dbSsmEzBRiTtjzmR/SDRczK29rIQRgN7Dp7dUMvFP5gs9El
RQWlMxdrvT+Sw0tjSoAnUwM28+1dciOkML9kT+Ocei2UNrZlshKewnBFTeJ8
lg6eWHlNzAwWgVntmNOMf3TQde5AeunsVtCWO728FaqHmvg3UTlZ9TD2CXOh
Y4Yegr5cXulaWAEXx/Wnp3+ej2l+F5lH0/p6sh5N+3eQ/fE1Pb+bnI8O9H43
yP3QdP9J5P54lb6vmLwPLen735L34xRaHwOpD3bS+u0g9cMeWt/VpL6YTOvv
TuqPN2l/okl/MJ/2bxrpH6bQ/q4i/cVfaf+DSP/xAtVHO9EHbqL6ERD9oJTq
6zHRFwqo/uKI/vBrqs9TRJ8YTvWrJPrFxVTf9UTfuJTqv5ToH72oP9qJP9CP
+mcR8Q+mUH9xib/wBvVf9sZx//3vz8PEn/CA+reC+Be8qb9vE3+DkPqfQ/wP
5ZQPOYQPoKX88CH8gGOULzrCF1hB+fMn4Q8wKJ84hE9g4lcR4RdoKN/khG/A
pvzTEf7BTMpHM8JHEFJ+Xif8hAuUr7MIX4FP+fuM8BeKKJ/lhM8w9iG/Yedz
wvdUwndwp/zfT/gPMpoPfJIP0PJhfoAdzZeNJF9AR/PnDckf+IzmE4fkE3xP
8wtJfkEIzTcpyTe4TvPPIWg8/0BG8zGc5CMcovmZSfITTPm6nuQrmPJ31Ofy
hGvdfJ9/AePXI/M=
          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVlWlQU1cYhlkkApJq2ro0igVNqKBAIVLW9rPiAmNbIzAEsDoWlbLUIraK
dMClqJQWFEUQsFigDoJbEWsFdfjESCRRUNlaoMQAIWQhIYuoLLWtnsMP7kwm
P+7ce8/5zvs+j2N0Ysh2CzMzs5T/f6/+iwpfXSowoxcDT9veXq2CjNwC1jQX
IY505DeF85Xg5X6w48WTFsxiWQdslSjAufpNuFLSjRMHfv8DHsjBu+bwslut
vSiyHkkWJPVBxMkjC08lDOCplV/6WFQ+ATvBjvqbx5W4l8loXzG/C8oeL4+M
X6PB6t0HY+y/aAM3g8sGp6NafGA1sU7EawLGtYTMjsRhvOpXfi/+Rj1ImudY
VKXosS+SxeP2VUIrJ7d54ywDrp+X4vDBYCnGiOP8KvcbcI/UddvIvDoMOsS8
NiQxYFygyeVTLzEWBfK500YMWBq3YMIt+THua4kRhZoZEcZKLmxhd+BnqVkp
Ep0Bz825cbEuvQuddrE6VfUG5L3fOBx1VYr5z6a3PfzOgE3ClVIM68XQE975
K9gG9OK9uvqx4J45t6pEj1tKc5jjT+W4qO/FkXVv6NF+mWuAsFCBfBeOh6VI
hxOKgncfOyjRX5TTPfdDLfpg1vf9P6hwvDv6uv6ABs3ZZ0pmPlLjiW9GZ8Xm
qFAzdDeyyKTBQM+KeM/4QXRXpTKbhofwncPBjRbMASzmMXeJUIvq5DzWreQ+
FFszIHiTDoOzmWnxoU/QPLXKPvu2DhXPch+4relE/28DS9gyHVqHYc5NSQs6
7jl5sb5Kh4dOp0r+eXgPhedl7kKuDk9vsU/zOF+NgZtdeCEeWqytt69Ye78c
XJ7pvy5s0GCzz8N2hl0DJI23CxI7VFgZZUpc5NkCCnFwwp2Ng7jWvWbWgspO
WLN8W1ZKmBzF+HlEUrgMZoeVWc0Uy7D849hPrqf1Q/Hr/HWio+2lI3lLFWBs
N9pEjz7C9Jhmvk+QEvJm59mopYhbBcXCHSIV+M3wVg4sPQG1OwfOKc6qQac6
fKhuyV3I3r5/W9OQGq53PdemV7TA8eix1oLLalCkaF3LaruAyxv23/lSBdPP
bmpYNK8XsrnHnTkGJQTdDB31PCAHvuQnqVPRINzftYrpnDsIL23t6vfaKiBc
K0owblCDY1l/cRBfDotNbRonHALL9F82WyT3Aafh7TZfqQ562R9tzc+Qwf4Q
857dkXoYZ/waeInVA/3SFS17HAwgr9TjhX//grj3wo+1NhigI7ri+T5ZGyw5
4zZks84I/r5fJQfVPgLO6JhfxBUjeO8Nihpmi2F+mXVUzagREmb81p1UdxsK
qlW7ezgm8LfUmPhYBa/jxzPRf2FAIb2/lNxHNn0+kzyPXPp+e/J+dKbf9yHf
x1i6vn6yPpxcv4ysHw/S/RnI/tCZ7v9vsn/k0PkwyHxQQOfnQOaHjXS+5jNe
zxdX0/mHkPnjW/R8Msn5oHbq+WErPd9j5HyxlZ7/UXL++NSG5KOG5AMX0/zE
kPxgD81XBskXnqT545D84Ryaz7Mkn+hF89tF8osamm9fkm+czP8Fkn+c7IeI
9ANX0v4UkP7gHdovCekXOND+ZZP+gQ/tpx3pJ1jS/naT/kIj7bcv6Tf8TPsv
J/0HV8oHNuEDKCk/VhF+gBXlSxbhC/hR/owR/oCJ8mkV4ROwKb8iCL8glvJt
IeEbeFD+FRH+wZ+Uj3zCR/Cm/Mwj/ITiqXwFD8rf9YS/cJnyOY3wGRoovwsJ
v8FE+b6W8B0Ec6fwH/ypH9qIH6CH+uM+8QfIqV+siF+gnPqHR/wDqVP9BKXU
X9OJv0BM/RZG/AaT/vMj/oNU6scdxI8wQf3JIv4EK+rXHOJXmPTvy3N3Fwp+
vBPwH97WD8g=
          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdlX00lFkcx8WOslGnzqljW2lZqqPSyzpLNP2mSS/UjuiNJJUiHVbRi0ZI
adv0cqwoZBO9UBF1ttDST6KRmsp4LVNjXpjwDGaaiE5suXf+mL3nPOc5z7nn
Pvfe3+/7/Xyttod57TQ0MDA49PX59g4cGe1gQMdY1n2TJFUbnORKsu3in+CU
tPRjf59TwG+JF0v8PzVg9GjPONdjMjjdJ+mMKpHgJ5F34XmFBPIFrHFF0xV4
uOyfhOIZb8BQUGArq1PiKJl08LF1PXTxi2ZaMZ3oum9/2lyb5xAcP913dowK
eV4VAQbscoj+4taTk96Dk6703jsw7gp4z5cVPsjtxaKnsfKa67mYN8nBkeut
xjtnHf9cGVWOnw9s3VsmVaP7MPeTw6watDGTZMncNNiiDDTpzqhFWbGta3Cy
BgVfnApqGxpwYtB2wZxKDWY6v+EUPn6N91XDzNoWDZ74cCrq6u63uGz1YNeO
r9/xRx7mnAlqxTCLWcm7qjT4zLDsVvWgFJVsv4yBNA16nPiJP2+vHK3OR2av
99Hgq+ffhgJdUkOig400OKejPjB0fDtaiPsOv7mgRt74I+wLzkp8YZc502yy
Gg28k/zCPN5j5JfsMXbRvXgv3Ph6Fq8DL25XTeCm9qB/eIrrEqdOjPe05Xgb
dWOjcdXxy2O78NDN/U5XnRgM4MaMnirowlFCy+oGh05krrEeiYMYXDqGvYWn
VeL7TtsnBzsYHKq9IWZHtKGXg3lywjIVPvDjTGvKl+H71Uu/s49QYWTQUKjP
EgmKAlJLNwSq0G2s2CIzqRnNmhOW2o1XYUu9cu0tXi1y4gL8InwYzA3hHVT3
V6BJd+yZlNldmFd988e4uiSMYH28XxLSgb7XYv+d0loGWe5yZsNQO07OErA6
fnkFfMWpay5COd629Le6kNMMD2s3TT2RL8G6xK2rBma3QvCI/hpRvKupwTpQ
DnV7rJmFvtW4b5u51uhFG/CSGx+5PE/F6I3RoZ89lJBs6nbbjXkE9c/WRt7t
U0Kf419lYq0IfEv373wgU8JZy1WJ4fPFUL5HZLGcrQSnRI3/hJUyqJDIa2zs
22GYP8fP0vir3tMX3GlsVAC8zLkyeWMHiPtbtnp7yqGUq0hdzmXgo33VzepC
KfTMW8Ptf9kNKcIZHvmGreCu/EFrE98LSkd7U/5lMbxdcGp43SE1mNkYPlMt
fg22LebGNe4aOOfmc2RA2QAtFYW3XT9rYNOKS3m/Z4rg9Yq4u6ZnPkDCjN1B
i4UvYOGv7eqBUVrIaLIwn8avBk5I7tEYXy0U9HM2a5dUgNnJS9qCdC2smy91
ESwuBnYxv5dXroUwjmPhjrm5IBzRn5a+Kxfp5jPIPI6j60PIetT9v4T8H53p
/ilkf2ym58sl50Pd+TeQ8+N0er8/yP1QQu9vSO6Py2l9Bkh9sJfWL43UDytp
fRlSX1xG699M6o+6/rBIf9CF9q+S9A9v0f4+JP3Fj/r9x/X6+sCjVD8xRD/4
P33hNqq/d0R/eIPq8x3RJwZT/QqJfjGT6tuc6BvDqf5jif7xe+qPx09H/AFs
6p8k4h8wpf5C4i+opf7bQvwHCurP08Sf4En9W0r8C3LqbyPRiL9B539n4n/Q
8YFF+AB1+vwAX8qX44QvcJfyJ4PwB3R8Okj4BGsov4SEX2CnzzeoofxbRPgH
Xvp8BBHlZxvhJ0RRvoYTvkKcPn8hkfK5iPAZnujzG5oo3+WE78Cl/Lcl/Ie3
+vkA52h+5JP8gAPZJF82k3wBT5o/sSR/4GeaT2Ekn2BQSvKLIfkFoTTfzEi+
gZTmXynJP9hH8zGP5CNY0/ycR/ITTGi+VpF8BV3+Dk1knE0Xli/6D8BNKrk=

          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVlXs01GkYx6VFU6i2dLrpohW71bG1iTJ5pIbF5oRQql2RSyqX0rYoim3S
VmwXLdktlamWjlY4o7U8kSPkmihrMcyEmSmNGZco2fK8/vCe8zu/P97z3p7n
+/18F3sFOfuoq6mphX38Pv2/GR1iUGPjkmufRklkO9ir2UmTHMvxs8dBkTHn
RBB26ULbjU2N6DWvejgztgm+dO7boN/ahkKtdd6r9eqhc7JOtadFB3KSj6Vo
ZFdA3FFRzrkKKeYLXmS9aCqAqAVTlRVZr1CQGFE7MOcyWGzd8GH39De4Nn0k
7NTy+1iiwU8yPK7A2MZAS49JxYhuhur19j14wpqvnqlbhQMZOsYFih40jok9
e+i3OlwW9iGh6ogSi4ojigcfPMfeoTS3bRIl7nCKSC083ITKhFnXQtaqsFs6
LOI+bUHcujXRMkyFG3ckKk/KRfgtJ3DYWKDClc17vxfx2jHCKfwsp0CFYv0P
Di0RYkyZdiDNpliFJU+GqnTOS7DQZNYzmVCFp1elVtbFvsTwhk1l2Ykq3Ov7
aXTgf/7P6w18VRi/27ygZHknmvXkrA5fqEI7oX1Hbksn5k+ssnjySIn6x6cn
5EZ24asou1KlkxLvCb+2lupK0Zt/xyKptAeHdK0qR36V4qmUXZtMlvbg7N1z
jZdoyvCXoZi0Ln8Fmjv2738YKEPe+i3yAP03uMs2dMXmchlq9R/9IvSr19hd
k+yjmCXHFROzBfEqGTrePKap5STH9en1lpkHu3AbRJqHHpTjjCO9RkbXXyL4
ifxuh8jRqmsfr+JIO2pHvC/gWsmx1sxXbNDajBMWjDgvLJPhnz4h6kEaDeil
nlG0pluKft6J52Lzy3E+p6ttBb8LvfJSLGaX30M/d0mZ284OdHHw4CskQtDb
abi8yEyMAcfyXHicGjhj5DuiaG/G6/lh1WaHG8F0VH91mPh4guFfKSJ4pvv5
qv0B/6B4wVQva0cxWN+5e6DPKQf6J92e23tLAvsuDia8M6mFC8kPnfOaJMCf
fNnTaKAJVo44O6ClBP5IjvMwLWyHLO/wC8v0P67n/MxNfd0BafsagvUy28Du
arDagXgZbDePO1uzWATXdy5yNxe+his2Vk3D05qhdUh7D2+dAp7uv5urIW2E
t0nxN7cH9MAPPmcMLjc3fNxPoecaogSHlvPa897WQdvMRi2BiwpyRzKnh3Fr
4eC7pGs1M3sh7u9DDm2ulaCZ/l1FirAXHtZGB96LLoX5pq9arS37QM8mprRy
4BEE22+u2ZPWB56Z83U03BHUq08FOwz3wbYpaw0sDYUQW3jDQ2zWD91RGhxV
TAZo23fzKj36Id7pwRKB41UYlZ9vP/uXcKew+R6aRz5bb3RidD1OYPtvpP1x
7Pyf6Hycx+5nRvfDsftX0v0xlL0vlN6HYvb+dHo/bmT1saX64CCrny/VD0Ws
vv9SfTGV1T+R6o9OrD/u1B90ZP27Q/3D26y/96m/eHJ8/9GT6eMi6QNzmH4G
SD8oYPqSkL7QhOnvCukPDzN9ZpE+UZ3p93fSL/ozfc8hfeMcpn890j+M+SOI
/AEj+uSfbPIPTGb+KiR/AZf5z4H8By7Mn7PJn7CF+deC/Avy8f4Gd+Z/TfI/
mDI+2BAfYAbjx2niBwwzvkQTX+D+eP7AIsanTuIT2DJ+IfELLo7nG3gz/rUQ
/+DMeD5CGeNnEfETZIyvV4mvsIjxN4r4CzzGZ1viMwwxfhcSv8GN8V1FfIdq
xn8l8R8MxucDZLP8GKT8gGiWL0WULzCQRvlTSvkDrsmUT2son8D8FuXXj5Rf
UHiF8u0a5RtksvyTU/6BI8tHLuUj6LD8dKH8hPMsX/0pX2Esf9+/W5oRXZ3H
/R+A1A9l
          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.811582390749806*^9, {3.811582663586135*^9, 3.811582683224318*^9}, 
   3.811582720719016*^9, {3.811582757146151*^9, 3.8115827834726133`*^9}, {
   3.811582889884184*^9, 3.8115829060532513`*^9}, 3.811582938095173*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"d7add486-b7d4-47fe-82d7-30751960e773"]
}, Open  ]],

Cell["\<\
Plot points along the paths of orbits at the 5:3 internal resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"735cde65-5a7a-4f86-b960-1f5b3066f059"],

Cell["\<\
p1 = PlotPath[{3,5}, 1.0, 0.1, Pi/20];
p2 = PlotPath[{3,5}, 1.0, 0.2, Pi/20];
p3 = PlotPath[{3,5}, 1.0, 0.3, Pi/20];
p4 = PlotPath[{3,5}, 1.0, 0.4, Pi/20];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[11]:=",ExpressionUUID->"671bcba9-652e-4534-9f11-acbe0c9197c5"],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.811581966195409*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3ebf6884-f27e-4477-9c97-ea903dbb0ede"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{3.811581968811892*^9, 3.81158229921481*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[15]:=",ExpressionUUID->"6e4ea90d-e7bc-459e-8310-8ac643572809"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdl3s8lGkbx6eV1ZYcihzafUsRHTdbKZKLDrRCsivpbeW4qFWIl6ReRBLl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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdl3k81fkax89N2iRRWkTXNlIu06KNqQcTw5AiDUULVxqFxhIlomwz1KDy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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdl3k01Vsbx6Vyr0qiVO41pChK14sSRY8MyarQcE1XJ8oUMjVpEJnqGipS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          
          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdl3lYjOsbxwtJllCnOlKNooOKcgkp3EWWVkRpQSftKZK6rmONScRBOEX2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          
          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.811582391267385*^9, {3.8115826642407427`*^9, 3.811582683979681*^9}, 
   3.8115827212805567`*^9, {3.81158275768859*^9, 3.811582783989831*^9}, {
   3.811582890375207*^9, 3.811582906579474*^9}, 3.8115829399194508`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"4de879d7-c3cb-4057-bbb3-952d9a0c0d77"]
}, Open  ]],

Cell["\<\
Plot points along the paths of orbits at the 7:5 internal resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"49b53d32-6f8c-4fca-bb0c-10392f73c8ba"],

Cell["\<\
p1 = PlotPath[{5,7}, 1.0, 0.1, Pi/20];
p2 = PlotPath[{5,7}, 1.0, 0.2, Pi/20];
p3 = PlotPath[{5,7}, 1.0, 0.3, Pi/20];
p4 = PlotPath[{5,7}, 1.0, 0.4, Pi/20];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[16]:=",ExpressionUUID->"18cb604b-3ed3-4ee4-93ef-c3f4040ebfbb"],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.811581975781055*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9081f893-8f5a-4484-b76d-f552436bc570"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{3.811581978920745*^9, 3.811582308896565*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[20]:=",ExpressionUUID->"156df09e-2f1e-4e60-b0d7-e7ba0945b803"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmGk81GsbxyWlCFkia5a0Uk+bSnSptJA650ghCpVKTpEspRIdSdJKKUlS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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHkglOsXx8nWQrmSIlEKSWjf6xQil4rotlBZQ6nULSU/JHFzXbIUlSRJ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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmGkglfkXx201jSiGCSVU0l9Ju5J0VJZKKpXUpDAkWaJSJi2iRauUm1ZK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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHlczXkXxxPtWSJSiqKI0CKRqU41JKRCIdmKmiGSFGN5Ci30YJhKZctS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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.8115823919189796`*^9, {3.811582664904788*^9, 3.811582684889001*^9}, 
   3.811582721875477*^9, {3.811582758274067*^9, 3.8115827845806*^9}, {
   3.811582890934248*^9, 3.8115829072000113`*^9}, 3.811582940519032*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"d6c01449-5901-42c0-9614-950abffa6bcd"]
}, Open  ]],

Cell["\<\
Plot points along the paths of orbits at the 9:7 internal resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"921896c7-1434-43d5-81a4-9176528d35d8"],

Cell["\<\
p1 = PlotPath[{7,9}, 1.0, 0.1, Pi/20];
p2 = PlotPath[{7,9}, 1.0, 0.2, Pi/20];
p3 = PlotPath[{7,9}, 1.0, 0.3, Pi/20];
p4 = PlotPath[{7,9}, 1.0, 0.4, Pi/20];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[21]:=",ExpressionUUID->"db74964e-0a1b-48ab-ac44-b8201a1db981"],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.811581987551469*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b37af609-d9bb-4384-8138-760dd97ec607"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{3.811581990320097*^9, 3.811582317934691*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[25]:=",ExpressionUUID->"0ab9b41a-ea3a-41e2-9787-d61d94fd8396"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHlYzOsbxpGU0kK0SNa0HFtEtDhPWZKSrZBsoRJJVNYiJVqISNoXtP1w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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHk81Pkfxx1dWldqScd2KbZDhU7ZNxXJ0aFUUqncOSpEv0SpVVupRG2H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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHlcDPj/x0ttOpSESMiVUKgctbX1phyxqws50laycoQoR471a8VKp2hl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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHk8FWgXx2kPiSbti0S0kKZthplOIWXpTaKFCmUpNbwhWkRFypKQjLUx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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.811582393107687*^9, {3.811582665782464*^9, 3.811582685845725*^9}, 
   3.811582722525284*^9, {3.811582758882144*^9, 3.8115827852017403`*^9}, {
   3.811582891552672*^9, 3.811582907854196*^9}, 3.8115829412099943`*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"c890fb96-5612-4790-aba6-40bc361aa1a3"]
}, Open  ]],

Cell["\<\
Plot points along the paths of orbits at the 11:9 internal resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"db2e65f2-86fc-421a-8063-e105c6d06572"],

Cell[CellGroupData[{

Cell["\<\
p1 = PlotPath[{9,11}, 1.0, 0.1, Pi/15];
p2 = PlotPath[{9,11}, 1.0, 0.2, Pi/15];
p3 = PlotPath[{9,11}, 1.0, 0.3, Pi/15];
p4 = PlotPath[{9,11}, 1.0, 0.4, Pi/15];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[26]:=",ExpressionUUID->"172f91ed-7bd2-490a-a820-d7f263ea470f"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 28, 1, 25291197928573440596, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.811582393436768*^9, {3.8115826657890577`*^9, 3.8115826858539133`*^9}, 
   3.8115827228802958`*^9, {3.811582759170127*^9, 3.811582785472704*^9}, {
   3.811582891786077*^9, 3.811582908200674*^9}, 3.8115829415024357`*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"c6729bb8-f74d-4dd4-8cc5-d8c2e46deeb3"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 29, 2, 25291197928573440596, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.811582393436768*^9, {3.8115826657890577`*^9, 3.8115826858539133`*^9}, 
   3.8115827228802958`*^9, {3.811582759170127*^9, 3.811582785472704*^9}, {
   3.811582891786077*^9, 3.811582908200674*^9}, 3.811582941602693*^9},
 CellLabel->
  "During evaluation of \
In[26]:=",ExpressionUUID->"a7f034c2-2171-4daa-a451-21e5557f1071"]
}, Open  ]],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.8115819983536997`*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4c910f21-dc00-4331-8850-9e0da13fbbab"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{3.8115820020228043`*^9, 3.811582326219263*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[30]:=",ExpressionUUID->"13bb6f86-5389-489f-a0d0-b9316d1186be"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHk81NsbxyUVkaVwi7Jki5SUey8qT1RXOykV2iiiVUn5tUlIUtdStmjB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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHk4lOsbx6m0aLGkLCVtdBKpU6TQbSnxQ0qJOkqFHCWkiFaVypYiUiFE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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHlczHsXx1tELgpRrp3E1SJrytIp0qJLRCg7FVpJJFuWukKWKFG2stMm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          
          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1mHk81HsXx0niFqGFErmU6oqKNkQnkixtStqTLUvSLUVK271pIW1SdNUl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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.8115823938686523`*^9, {3.811582666628039*^9, 3.8115826868097067`*^9}, 
   3.8115827232901983`*^9, {3.811582759559013*^9, 3.811582785863327*^9}, {
   3.811582892144552*^9, 3.811582908594769*^9}, 3.811582941971291*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"4a4a82c8-be25-4972-95f2-7b7d6ddb1f73"]
}, Open  ]],

Cell["\<\
Plot points along the paths of orbits at the 1:3 external resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a0aaeb9e-e8d0-4933-81b2-48bef8ebacd6"],

Cell["\<\
p1 = PlotPath[{3,1}, 1.0, 0.1, Pi/40];
p2 = PlotPath[{3,1}, 1.0, 0.2, Pi/40];
p3 = PlotPath[{3,1}, 1.0, 0.3, Pi/40];
p4 = PlotPath[{3,1}, 1.0, 0.4, Pi/40];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[31]:=",ExpressionUUID->"561201e5-1a3e-4fce-b53e-adf521c364d8"],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.811582008273028*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d147f321-05fb-4ed7-8f18-0f92117e4432"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{3.811582010841504*^9, 3.811582335788679*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[35]:=",ExpressionUUID->"754d3663-a6d2-44e5-b98b-eb828c2ae4d6"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxt13tQlFUcxvElyRsoqDUp5FCKiBmUhZcCO4Z4Iam8JIkWiIlpSsikCcRF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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxt13tQlNcdxnEDisSJGNEooRDdqpFURFtT0hDxB2Ei7YQOVE0EGggBQRQF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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxt13tQlFUcxnGCiszITImoLEAp0bK4BMTtiBcyHSBAFDSmsojMsZS8hKEl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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxt1nlQlHUYB/DlCBAsPEi8FdcDL9LBI0B5RHDF6BBIMDBNE5NSaSTDsQzM
izwRyYwUm9QKiMME3WD1EaZ0PIJQRBAFbEFxQDlXEXSpeL408+64Mwx/vPO+
+3t/z/f72Z/TsoiAMHOVStX0799//127PnpS4RPbfjuizE9PP/V88pkh+gDN
861P84jXk9Wp6OsRHj9TelbrkjMderqTETdyrSaLQvJ08y2jqunUNzO+n3nh
LEVu7PA+Vl9NLZfaK4Psz5PKULBTM6uGEn5Lfd3bt4AyIws7FgTUUMATrb2l
dTHpHNP2DzWvIV617a91h8uoV1hI1sxJ1bRpmWVqeF4lHfluT8jUvL/p5Psb
4scP0VPAhkNVjUeq6HJh9tDDS+6STfn5TQ4x5WQc/q1D/ef3qbfL4mlzqJhU
r6QfSphTTwXue10Pj7hAVu6bHwTHPqRatePbuRMSyfHYr8MO2TaStVnfu3F7
8tlnbOAtv/cayW5uZk5sUTGv0faZM9K1kRr7L/n0qqaKG18qiQytf0jTG+zU
P3TW8L2CM56f//v8+Uc3Wln717FH6nXPE2trqd/kXX7ebQ3c7rHvzdAterr2
fnX5jZtNHFGRVKmbUk7Zk43XXJ1buOOdF3OSdl+mBW6fcNWVFubNL59dPf4r
th770SUXbQv/6ZTg0ft2IWsex3m/caeZXVyC57n3rGTDlZ1FI3ybeOiPi7xe
4Lsc6Vl7ZGXdAw56dKi84q0HnBrqHzyi7R6/Elrz+gfrmtgv9GDz1roq1vRY
88z5eAsn1em3OvS9yqOeTrL7cqCBDfEVUwb7JHDOCxa/rTpn4PTkfiGJFwtp
9XK9Z9EOA5/7wk4dE1xFPb3CVMFRreywzWfH1Um1tHLgonDt7maOP1Jx4/To
BrriFNI2iht4+pPmRN91zfSDWfvVlfb32Zjn0POdw61UFx6eUeZ/h9P1QyxK
mg1k7Ezef/1EEa/o+jyio2/cT1uZrdVl4nqJXKfu++vlfnLD8xPl+RSL7y+W
76dBWF+YrI8qsH4bWT8VKd+Pru9TvD+dxv6oZX/IG/s3T/aPjmN/XWV/KQr7
7y/7Ty2Yj5PMh3wxP7XMj2ww30EjuuZLQZh/oMz//3w0SD64GPkJkvzwIOTL
IPnit5C/GZI/9kA+ayWf3Ib8PpT8ciDyHS755uXI/2zJP5eMlH70l37wafTH
VvrDfdGvTpeufnH1TemftVNX/3gR+pkv/eQf0d806S/bot8HpN+cjf6XS/85
GT5sFB+424908YPXwpfpl7t84SXw51Xxh9Pgk3tml0/8GvwKyO7yi7t9SxHf
uNs/orPOqb+zrvt6sp3454v7C7PEvww8v83Ev/3wr3t9fWR9ZIb1x8K/k3i/
mfAvB+9/ycS/LfAvDft3DP4tx/7mwD9n+NcI/yZgPkaZD93H/Kzh3xejlf5N
xPy94Z9BI/mIgH91yI8B/k1Evhrg3xzkzxf+9UE+zWaIf5eQ31z4l4N8P10o
/nXn3y1a/OuBfpSa+DcG/j1Fv4zHxb8w9G8p/DuJfk6EfwHorw/8K0O/h8O/
lxOk/7nwr8rEv0fwwwL+2cGXcPgXDX/08M8FPuXCvw741Qn/foFvo1Upz/Gv
VJeB643wrxP3V8O/qXj+MfiXge/PgH/GrbK+CPhnHy3rfzZL/PNLkff7EP6N
PqB4f/LH/oyFf0uxf17wLx/7Ow7+rVX+/pD5nzKfVpkPzcb8FsI/K8zXHf4F
Y/6aveIfIx/fSz74IvJTCv9cka8C+DcT+QuEf17Ipx7+qQYo/bupzDfHKPPP
quHSjwHwbwz64wj/bNAvczlf8G349xL8W4h+nod/8ejvBfjniH5Hwb+z6H8O
/NPCBxf419EqfuTCv0+V5ysOhT/P4N8p+DRMfOK58CvOxL9nvZ/nX6FuO64b
7ZXnvz3w7wSeXwb/3sX3qw+If2uwvrfhnyX8Ww//UvB+i+Hfebx/Avwbgv15
Df6tx/6VwT/C/t6Cf5bwrxP+TcV8HsO/DR4yv6du4t98teL3jQaay/y94J8a
v48r4F8N/GuDf87IVyv8G4P8hcM/J+TzHs5/echvr0qlf4Nx/gtE/n0ilee/
LPg3D/0ZCP96oF/F8G87+jcD/n2Nfk6Df5vQXzf4943J+e+PvdJ/HfxzSBUf
wuBfIvzrA//Gwb+l8K8E/uyCf+PhUz78M8sXvyrg30/wbZ+Jfw/VEw7mJtXo
UnF9mlwnW9z/q8n5Lwn+afH9KfBvPta3AP5FYv2DcP7rD98j4d+oHUr/PE38
C8H+ecM/I/a3L/xbg/1/D/514vepHf5Nxvw64Z8F5hsE/7rP/5s3in+nkY9M
nP9KkR8P+LcY+doO/6KQv8Hwzxb5tCoU/6zgXx38W6XMNyeanP9cxyj9a4d/
KvgXN1H6NQz+uaB/9dI/Hod+NsE/LfqbDP8c0O8Y+HcU/e+/WumfG/yzgB83
4V8EfDHCv0D40++g+JcJn2Jw/tPAL41W/NsJ30ptlP59nLFnccy1G7p/AIz8
/SM=
          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.811582394450138*^9, {3.811582667302606*^9, 3.8115826875782557`*^9}, 
   3.8115827239129057`*^9, {3.81158276006005*^9, 3.811582786386889*^9}, {
   3.811582892646833*^9, 3.811582909183052*^9}, 3.8115829425768023`*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"822356a5-34b5-42fa-84eb-6e1f0a903e31"]
}, Open  ]],

Cell["\<\
Plot points along the paths of orbits at the 3:5 external resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9534fd84-763c-43ca-a520-6f73df69a93c"],

Cell["\<\
p1 = PlotPath[{5,3}, 1.0, 0.1, Pi/20];
p2 = PlotPath[{5,3}, 1.0, 0.2, Pi/20];
p3 = PlotPath[{5,3}, 1.0, 0.3, Pi/20];
p4 = PlotPath[{5,3}, 1.0, 0.4, Pi/20];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[36]:=",ExpressionUUID->"86968e43-fb20-4329-8782-5dff24b4a03b"],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.811582017815896*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f309c358-9a30-48d2-a0f0-99f5d46e5baa"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{3.811582020611702*^9, 3.811582348658025*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[40]:=",ExpressionUUID->"55d394dc-19a3-4b76-a5d4-385a4a9fa5f5"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxd1XtQlWUeB3B0kVBnJbVNSZlkXGBCrNANNoT9oVxUyvKwyh1lRZQTGW0e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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxd1nlQ1OcZB/AFrWgKwYlGZWXTsgQwRTRyGI7Uh9KEqjWKSNpEMDpERZAm
pDZeGE1VsIpHFM2CBOQwQKwohxFU5AEBCYgoINdC5Vxk2QV21wpe0cZ9v3QG
d4bhj53f8b7v9/l+1ib4c/91phKJpPKXvxf/T8a/+KhJgk+4Y6jZmnw1RegC
s9VOx2j9qlRJt3k/LWxxmNG28DT9OtF65pXD/WQblm/mUZpD8+peXSL/nYYW
JXjNSn6nkGYN6z6LL9dQr/uthgnm5XS8cp7vXB8t2cqDyqTKm7T7A++qL7/S
0nSnuCCNzx1KsWzZNDFAS405NpGL/66kh0r35tDTGrrRYlXxaWYHBQxc32hY
3k92qd2JC/166KK+xX//n/rIOfuCR9mkPjq/RpLSu01FN19r9WvP0NCkD4uq
3lJ30v7wBdujHw/Snpv3Hnv9sZXkYdl7mvt0lBZq/XTOllraWbf++gqJgW5l
OcRS/WWK6nO6fzzbQLIa72Gns7lcox2+JdUYaLyXSeURn9v8XBEll2YYyOmk
TD77+1YernDwce7Sk5vLi083x1WY2GUn6+hT0wW2ayb3cchS36w85QBJxi/z
nLpAyyX7frM0JkdNBVa6cUXxQ7xhfuLEWF0PSQuUJY4T9Ozp0RUUdKydwh3+
cqS+XM+lwZkjOzvu0LuWIRF/tjCw4mpU8rOwMvqh6oJ0WY+e14Zkb7680Zdz
G+tW2X+k52RHl6EDr5eybcQD85jtOj7Y7VLUOq6OTXdkyw4VD3LXcGz1HN8W
LqiNqvElLcd51q5Z7t7Ob589tCktUc3zf2/1h3ZNJ+9oS1p/Zfw9dq5KiFYk
dPPXhtOTMxU9PKnc8p+Xrvbw9YkPtvz1iy7+6Hj0G4qNKuYyb7l5Wgfvjonr
fXxNxZWX3rzuFXKXk5ccnH62W8W5GZXFZtTGe2VyE/sBFd8J2LrfN0/JwT/v
mp7xVMVxxvy1sO0rWdEnHHv5ucnKqG1XmlndZrpu2uFefn1KpHeRsomnJJy+
ljfvHr/39dQIz4uNrPLY4z7Fuo9HpN+tmP1qA6ufndIMLlLz98qRgT2ZdXw8
+HF93Ll+3hzk0mh9poaP3rR39nbVsmVZ1GF1VzkXdNxztbg6wKdmBprOyvuR
p087s3O83RArmpMqkwJj6aBXiZevXMclnukVYZdLqKpmmmn2Nh3/9j82h60C
a+mRX4h5S5SOQ+IXu1WHK6l5cMWElPk6Ju9/h/2jvZNOzmjbYCMZ4tx3VnY/
3NpLrWtptf6ilp9YJSVb3u6nE5seTd7wjZr3bvc7OpQzSGEX+vOfKFRcZhXU
mTKiI1manyJV1cHXbodYnptroKV+TQPLPZr4Uoi9NFJvoKpf2QWVplewMX4u
96nhzs6ICqfywgJ8P3eC8Xsqw/Vu4noqxP3fF/enzXj+LvF80uD9MsT7URbe
/654f3LE+jLF+ugTrF8p1k/TsD9PxP7QRuzfDbF/9LRlzP5S+dj9J3WpOJ8i
cT7kj/P7Vpwf9eB8D4rzpec4/z5x/hSJfDSJfJAb8mMu8kPWpiJfnSJfdAr5
sxH5o1Lkc73IJ1Ujv1tFfqkW+U4S+aZ85H+fyD8VYT5Wi/mgzzA/UjE/9C/M
l1zMF7lg/pzF/FEx5vMLMZ/0Cub3kphfssF87xLzTdmY//1i/ikT/aCYZOwH
8kR/nBX9wX9Dv5wR/cIy9I+t6B8uRj99IvqJR/vrJ9FfvBr9Fir6je3Qf4mi
/9h1bD/yVPTnM9Gf3FM9pl85F/0bLfqXi9HPO0Q/8xb0t53ob34UIPr9hOh3
/gH9Xyv6n3+CD28KH/hj+CEXfvCoL1XCF86BP+nCHz4Cn27MNvrE38IvrY3R
Lx71rV74xs7wb4nwjy3hY0qo0UdeBz8Lmo1+chh8zbhv9JVH/TULmupin15b
+H9/9cLfYFyvVAp/LXD/LnF/Gn1+3knhrx3e7wH8jcH774K/m7G+D+BvEtY/
CH87sT8D8NcL++cDfzOwvz7wNwn73wB/B3A+8fBXhvNzgr9nXvI34CV/pyAf
t+Dvl8jPQ/i7EPm6D39XIH/fwN8o5HMx/K0fJ/I7DH/bkG9X+DsD+feHv2GY
jzb46475SS0a629/+nmjvxcwf47w1wHz+SH8fRIp5td8RPibhfm+Cn/NMf+f
w99V6IeV8Ncf/eEKf/PRL2vhbw765xD8TUI/XYS/seivGPjbhX5bBX+Pov/s
4G8X/DXAX1v0pwX8tUC//hf+9qN/VfD3Nvr5APx9G/0dB3/Pw9/z8Hcr+t8K
/jo1CR/2wd9jL/mrbRO+mCwX/jrCn1b46wafUuFvHvyqh78WUuHbXvirgH8f
w98f4WMQ/K2Gnw3LhL+F8DX0JX8XqefYrZb//G4uvn/LTPh7Bdefg79ZuP9X
8Hc3nr8F/g7D31PwNwHvPwB/38D6GP5uwvob4a8z/H0Gf2VeY/aPltSL/T0A
f8Otxf5L4a/b2N9HVBQozi8N/n6H842Dv7KZ4vzvwt9k5KMB/j54TeRnJvy1
gL8q+FuI/M2Av/8D7qW/7w==
          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxd1X9czHkeB/DoB2tTKyxnW61csXvOY8VZm+pdo0FsWNR2e+XhRxtru9Uq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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxd1ntUlHUaB/CJzUuidDRUWEWUUlkx0EYGEZzHZgEFIQulQvScEkPkKCgd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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.811582394989781*^9, {3.811582667966756*^9, 3.811582688292384*^9}, 
   3.811582724448057*^9, {3.811582760627655*^9, 3.811582786962035*^9}, {
   3.8115828931885653`*^9, 3.8115829097215843`*^9}, 3.81158294310887*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"822a80c5-e668-4798-952c-e8649623f983"]
}, Open  ]],

Cell["\<\
Plot points along the paths of orbits at the 5:7 external resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f42e3ea0-e165-4455-9c77-b208940c6418"],

Cell["\<\
p1 = PlotPath[{7,5}, 1.0, 0.1, Pi/20];
p2 = PlotPath[{7,5}, 1.0, 0.2, Pi/20];
p3 = PlotPath[{7,5}, 1.0, 0.3, Pi/20];
p4 = PlotPath[{7,5}, 1.0, 0.4, Pi/20];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[41]:=",ExpressionUUID->"da815a41-bbdd-4c45-95cc-a115a4693fc2"],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.811582027995576*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7b728f15-e606-4097-a20f-401a758dd843"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{3.811582030947783*^9, 3.811582356311933*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[45]:=",ExpressionUUID->"e3d9516a-b6a3-4422-a0a4-2679864ce7ac"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxtl3s81ncbxx0maXOqLK2jUCmdQ6GuVFItVtRQnkS1kklMUjopCmvW1EQH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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdl3lczXkXxxvEYyylhFKJmJrQjLRNyZlJNZXKMpMwBtNYypKdIgYzYRTR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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVl3s81fcfx6l+RSx2SbQUJlmsRlJuvY/CCFGJufWrSUoiujOxXLYiplzb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          
          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdl3s81fcfx0mR3Fsxv7KuElpqiZDeawlF6WrUmntSoqTEakuTJS3Vuugm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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.811582395572513*^9, {3.811582668620141*^9, 3.811582689159342*^9}, 
   3.8115827251230803`*^9, {3.811582761177122*^9, 3.8115827874821663`*^9}, {
   3.811582893695403*^9, 3.811582910330469*^9}, 3.8115829437479153`*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"e744c88e-b5ad-4e85-8617-9b63ed323c08"]
}, Open  ]],

Cell["\<\
Plot points along the paths of orbits at the 7:9 external resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5c79ecb5-8233-4462-9cab-1543dd46b2d0"],

Cell["\<\
p1 = PlotPath[{9,7}, 1.0, 0.1, Pi/20];
p2 = PlotPath[{9,7}, 1.0, 0.2, Pi/20];
p3 = PlotPath[{9,7}, 1.0, 0.3, Pi/20];
p4 = PlotPath[{9,7}, 1.0, 0.4, Pi/20];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[46]:=",ExpressionUUID->"f75d6923-d667-477f-8dd3-604a116373b6"],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.81158203689955*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"35fab38c-632c-4664-bfd0-cf140d8d2258"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{3.811582040034093*^9, 3.8115823639298162`*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[50]:=",ExpressionUUID->"ba352fa5-7fe2-4c89-89db-ac3d8fcbeadf"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdmHlczfn3xy+hkrEvLSKaCCG00HYiaSQmZY1BlsjQhGyRmSlJWaJSUmOS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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, ImageScaled[{0.5, 0.5}], 
     {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHlczHsXx4cW281yb+J5LKnIXhKylGOna4kryw0XSZarzZYSIXXrJksS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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHlczXkXx7OEGiGjRkhF1ihSlpSTSpFsoaaILGMJU2hmlDJSeAaTUJaR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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHlczfn3xwtDYdS3QZKUbSSEaEE6ZV8zjCxhmCLKtwgRY8ZMhaLFUmpI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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.811582396225482*^9, {3.8115826694454803`*^9, 3.811582690170436*^9}, 
   3.811582725741561*^9, {3.8115827618628073`*^9, 3.811582788169158*^9}, {
   3.81158289433916*^9, 3.811582910983671*^9}, 3.81158294440387*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"6c40796e-a3c0-4d6b-9615-cd11edc42ff3"]
}, Open  ]],

Cell["\<\
Plot points along the paths of orbits at the 9:11 external resonance for \
eccentricities of 0.1, 0.2, 0.3 and 0.4.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"db513900-ea4a-46a3-9b5c-fec56ac5caf9"],

Cell[CellGroupData[{

Cell["\<\
p1 = PlotPath[{11,9}, 1.0, 0.1, Pi/15];
p2 = PlotPath[{11,9}, 1.0, 0.2, Pi/15];
p3 = PlotPath[{11,9}, 1.0, 0.3, Pi/15];
p4 = PlotPath[{11,9}, 1.0, 0.4, Pi/15];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[51]:=",ExpressionUUID->"2b6e24ca-2602-4cde-97ef-64f344bdfd3b"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 53, 3, 25291197928573440596, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.811582396566733*^9, {3.811582669452009*^9, 3.8115826901783037`*^9}, 
   3.811582725987194*^9, {3.8115827621554937`*^9, 3.8115827884107*^9}, {
   3.811582894604178*^9, 3.811582911242783*^9}, 3.8115829446854553`*^9},
 CellLabel->
  "During evaluation of \
In[51]:=",ExpressionUUID->"874796b4-2066-44d7-9ee0-a06a3e73db66"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot", "lstol", 
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"", 2, 54, 4, 25291197928573440596, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.811582396566733*^9, {3.811582669452009*^9, 3.8115826901783037`*^9}, 
   3.811582725987194*^9, {3.8115827621554937`*^9, 3.8115827884107*^9}, {
   3.811582894604178*^9, 3.811582911242783*^9}, 3.811582944768588*^9},
 CellLabel->
  "During evaluation of \
In[51]:=",ExpressionUUID->"7e71a38d-3646-47fe-b362-991940437919"]
}, Open  ]],

Cell[TextData[{
 "Gather these using ",
 StyleBox["GraphicsGrid", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{3.8115820554725924`*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d2bee98d-3d3b-4cc4-9745-4ca66a940804"],

Cell[CellGroupData[{

Cell[TextData[{
 "Show[",
 StyleBox["GraphicsGrid", "Input"],
 "[{{p1,p2,p3,p4}}]]"
}], "Input",
 CellChangeTimes->{3.811582058794949*^9, 3.811582371566124*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[55]:=",ExpressionUUID->"9201043d-d855-4d2f-bf41-55f1b16ed5e6"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHk41fkXx1FaaKJtStNGIlqGoppGjqgspSTLVKMxE41KEjOZdluZNjLT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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHs81fcfx3WRbGqmFetCWmqK5i7F3iqW7hitUkq6EdlyS0q0KLr+RC21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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 360.}], InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdmHk81Pkfx0k5KqU2hK4tUWm3i5Kld1EIvw6/KHTpkogUOqTtogObLrJs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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {972., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.5, -1.5}, {1.5, -1.5}, {1.5, 1.5}, {-1.5, 
        1.5}, {-1.5, -1.5}}], 
       {PointSize[0.05], PointBox[{0, 0}]}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[2], 
         AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxVmHlczXkXx9vGkoRSFEp2MVkKzag5uEXC0yhNY8kwiBCyhGmbUoxSQrJm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          "]]}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.0000000000000568`}, {1., 0.}},
      PlotRange->All], {1360.8000000000002, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.811582396937105*^9, {3.811582670271227*^9, 3.8115826910797043`*^9}, 
   3.811582726358548*^9, {3.811582762585869*^9, 3.811582788743574*^9}, {
   3.8115828949905367`*^9, 3.8115829115972633`*^9}, 3.811582945025177*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"d9bab7ae-e7e9-439b-809d-f4e1e5e5b6a9"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{923, 626},
WindowMargins->{{12, Automatic}, {Automatic, 371}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"8ef0774f-fb98-46ef-9de3-2c4ac0dbe615"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 111, 0, 67, "Section",ExpressionUUID->"384fa5da-6304-454d-a112-e1d6b3a3ebe9"],
Cell[672, 22, 232, 6, 49, "Text",ExpressionUUID->"fd6f1029-ac86-4604-bcdc-afd5feebc4e9"],
Cell[907, 30, 188, 3, 30, "Input",ExpressionUUID->"f94a2feb-6fc9-4490-8bb4-d246ab9e628e"],
Cell[1098, 35, 172, 3, 53, "Text",ExpressionUUID->"d1965594-517b-4ce2-8e7b-4372f5329167"],
Cell[1273, 40, 198, 3, 30, "Input",ExpressionUUID->"2ab9912e-1ca2-4a06-8dea-8191f83f3abf"],
Cell[1474, 45, 387, 9, 76, "Text",ExpressionUUID->"7513f64c-6edd-4abb-b03c-69a5c75da418"],
Cell[1864, 56, 308, 5, 30, "Input",ExpressionUUID->"524fa5d6-4078-4d61-942c-1edbd3dd4b1a"],
Cell[2175, 63, 369, 13, 53, "Text",ExpressionUUID->"6366915b-f826-4109-8996-bf4f2704eaf4"],
Cell[2547, 78, 263, 8, 84, "Input",ExpressionUUID->"31f6883c-7284-48b0-ab8d-b6bf58ec233e"],
Cell[2813, 88, 429, 12, 76, "Text",ExpressionUUID->"ae5d1cc0-1b26-4be2-9f63-d3e13da369d3"],
Cell[3245, 102, 1096, 25, 372, "Input",ExpressionUUID->"1bbdbe42-6c15-4a92-a117-aaa5121ae5c5"],
Cell[4344, 129, 247, 6, 53, "Text",ExpressionUUID->"fa6b0c9a-760c-49c9-8daa-019f43e312cc"],
Cell[4594, 137, 290, 7, 84, "Input",ExpressionUUID->"7cf91013-d2f5-43f2-aab5-7be9457b1566"],
Cell[4887, 146, 270, 8, 53, "Text",ExpressionUUID->"fd8fa469-17f5-4d21-a504-5d0aae5cc2cb"],
Cell[CellGroupData[{
Cell[5182, 158, 300, 8, 30, "Input",ExpressionUUID->"8e37d426-a325-4eef-8597-181b45faea80"],
Cell[5485, 168, 10263, 186, 170, "Output",ExpressionUUID->"d7add486-b7d4-47fe-82d7-30751960e773"]
}, Open  ]],
Cell[15763, 357, 248, 6, 53, "Text",ExpressionUUID->"735cde65-5a7a-4f86-b960-1f5b3066f059"],
Cell[16014, 365, 291, 7, 84, "Input",ExpressionUUID->"671bcba9-652e-4534-9f11-acbe0c9197c5"],
Cell[16308, 374, 244, 8, 53, "Text",ExpressionUUID->"3ebf6884-f27e-4477-9c97-ea903dbb0ede"],
Cell[CellGroupData[{
Cell[16577, 386, 270, 7, 30, "Input",ExpressionUUID->"6e4ea90d-e7bc-459e-8310-8ac643572809"],
Cell[16850, 395, 15290, 268, 170, "Output",ExpressionUUID->"4de879d7-c3cb-4057-bbb3-952d9a0c0d77"]
}, Open  ]],
Cell[32155, 666, 248, 6, 53, "Text",ExpressionUUID->"49b53d32-6f8c-4fca-bb0c-10392f73c8ba"],
Cell[32406, 674, 291, 7, 84, "Input",ExpressionUUID->"18cb604b-3ed3-4ee4-93ef-c3f4040ebfbb"],
Cell[32700, 683, 244, 8, 53, "Text",ExpressionUUID->"9081f893-8f5a-4484-b76d-f552436bc570"],
Cell[CellGroupData[{
Cell[32969, 695, 271, 7, 30, "Input",ExpressionUUID->"156df09e-2f1e-4e60-b0d7-e7ba0945b803"],
Cell[33243, 704, 20337, 350, 170, "Output",ExpressionUUID->"d6c01449-5901-42c0-9614-950abffa6bcd"]
}, Open  ]],
Cell[53595, 1057, 248, 6, 53, "Text",ExpressionUUID->"921896c7-1434-43d5-81a4-9176528d35d8"],
Cell[53846, 1065, 291, 7, 84, "Input",ExpressionUUID->"db74964e-0a1b-48ab-ac44-b8201a1db981"],
Cell[54140, 1074, 244, 8, 53, "Text",ExpressionUUID->"b37af609-d9bb-4384-8138-760dd97ec607"],
Cell[CellGroupData[{
Cell[54409, 1086, 271, 7, 30, "Input",ExpressionUUID->"0ab9b41a-ea3a-41e2-9787-d61d94fd8396"],
Cell[54683, 1095, 25316, 431, 170, "Output",ExpressionUUID->"c890fb96-5612-4790-aba6-40bc361aa1a3"]
}, Open  ]],
Cell[80014, 1529, 249, 6, 53, "Text",ExpressionUUID->"db2e65f2-86fc-421a-8063-e105c6d06572"],
Cell[CellGroupData[{
Cell[80288, 1539, 295, 7, 84, "Input",ExpressionUUID->"172f91ed-7bd2-490a-a820-d7f263ea470f"],
Cell[80586, 1548, 797, 15, 42, "Message",ExpressionUUID->"c6729bb8-f74d-4dd4-8cc5-d8c2e46deeb3"],
Cell[81386, 1565, 795, 15, 42, "Message",ExpressionUUID->"a7f034c2-2171-4daa-a451-21e5557f1071"]
}, Open  ]],
Cell[82196, 1583, 246, 8, 53, "Text",ExpressionUUID->"4c910f21-dc00-4331-8850-9e0da13fbbab"],
Cell[CellGroupData[{
Cell[82467, 1595, 273, 7, 30, "Input",ExpressionUUID->"13bb6f86-5389-489f-a0d0-b9316d1186be"],
Cell[82743, 1604, 23642, 405, 170, "Output",ExpressionUUID->"4a4a82c8-be25-4972-95f2-7b7d6ddb1f73"]
}, Open  ]],
Cell[106400, 2012, 248, 6, 53, "Text",ExpressionUUID->"a0aaeb9e-e8d0-4933-81b2-48bef8ebacd6"],
Cell[106651, 2020, 291, 7, 84, "Input",ExpressionUUID->"561201e5-1a3e-4fce-b53e-adf521c364d8"],
Cell[106945, 2029, 244, 8, 53, "Text",ExpressionUUID->"d147f321-05fb-4ed7-8f18-0f92117e4432"],
Cell[CellGroupData[{
Cell[107214, 2041, 271, 7, 30, "Input",ExpressionUUID->"754d3663-a6d2-44e5-b98b-eb828c2ae4d6"],
Cell[107488, 2050, 12944, 230, 170, "Output",ExpressionUUID->"822356a5-34b5-42fa-84eb-6e1f0a903e31"]
}, Open  ]],
Cell[120447, 2283, 248, 6, 53, "Text",ExpressionUUID->"9534fd84-763c-43ca-a520-6f73df69a93c"],
Cell[120698, 2291, 291, 7, 84, "Input",ExpressionUUID->"86968e43-fb20-4329-8782-5dff24b4a03b"],
Cell[120992, 2300, 244, 8, 53, "Text",ExpressionUUID->"f309c358-9a30-48d2-a0f0-99f5d46e5baa"],
Cell[CellGroupData[{
Cell[121261, 2312, 271, 7, 30, "Input",ExpressionUUID->"55d394dc-19a3-4b76-a5d4-385a4a9fa5f5"],
Cell[121535, 2321, 12974, 230, 170, "Output",ExpressionUUID->"822a80c5-e668-4798-952c-e8649623f983"]
}, Open  ]],
Cell[134524, 2554, 248, 6, 53, "Text",ExpressionUUID->"f42e3ea0-e165-4455-9c77-b208940c6418"],
Cell[134775, 2562, 291, 7, 84, "Input",ExpressionUUID->"da815a41-bbdd-4c45-95cc-a115a4693fc2"],
Cell[135069, 2571, 244, 8, 53, "Text",ExpressionUUID->"7b728f15-e606-4097-a20f-401a758dd843"],
Cell[CellGroupData[{
Cell[135338, 2583, 271, 7, 30, "Input",ExpressionUUID->"e3d9516a-b6a3-4422-a0a4-2679864ce7ac"],
Cell[135612, 2592, 18282, 317, 170, "Output",ExpressionUUID->"e744c88e-b5ad-4e85-8617-9b63ed323c08"]
}, Open  ]],
Cell[153909, 2912, 248, 6, 53, "Text",ExpressionUUID->"5c79ecb5-8233-4462-9cab-1543dd46b2d0"],
Cell[154160, 2920, 291, 7, 84, "Input",ExpressionUUID->"f75d6923-d667-477f-8dd3-604a116373b6"],
Cell[154454, 2929, 243, 8, 53, "Text",ExpressionUUID->"35fab38c-632c-4664-bfd0-cf140d8d2258"],
Cell[CellGroupData[{
Cell[154722, 2941, 273, 7, 30, "Input",ExpressionUUID->"ba352fa5-7fe2-4c89-89db-ac3d8fcbeadf"],
Cell[154998, 2950, 23452, 401, 170, "Output",ExpressionUUID->"6c40796e-a3c0-4d6b-9615-cd11edc42ff3"]
}, Open  ]],
Cell[178465, 3354, 249, 6, 53, "Text",ExpressionUUID->"db513900-ea4a-46a3-9b5c-fec56ac5caf9"],
Cell[CellGroupData[{
Cell[178739, 3364, 295, 7, 84, "Input",ExpressionUUID->"2b6e24ca-2602-4cde-97ef-64f344bdfd3b"],
Cell[179037, 3373, 793, 15, 42, "Message",ExpressionUUID->"874796b4-2066-44d7-9ee0-a06a3e73db66"],
Cell[179833, 3390, 791, 15, 42, "Message",ExpressionUUID->"7e71a38d-3646-47fe-b362-991940437919"]
}, Open  ]],
Cell[180639, 3408, 246, 8, 53, "Text",ExpressionUUID->"d2bee98d-3d3b-4cc4-9745-4ca66a940804"],
Cell[CellGroupData[{
Cell[180910, 3420, 271, 7, 30, "Input",ExpressionUUID->"9201043d-d855-4d2f-bf41-55f1b16ed5e6"],
Cell[181184, 3429, 22163, 380, 170, "Output",ExpressionUUID->"d9bab7ae-e7e9-439b-809d-f4e1e5e5b6a9"]
}, Open  ]]
}
]
*)

